==> MandelbrotExplorer_v1_21.jar: mandelbrotExplorer/MandelbrotSet.java <==
package mandelbrotExplorer;

import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;

public class MandelbrotSet {

	final private double scaleR,scaleI;
	final private Point2D.Double leftTop;

	public MandelbrotSet(int width,int height, Rectangle2D.Double rg){
		leftTop = new Point2D.Double(rg.x , rg.y);

		double r,i;
		r = rg.width/(double)width;
		i = rg.height/(double)height;
		
		if( r!=0.0 ){
			this.scaleR = r;			
		}else{
			this.scaleR = i;			
		}
		if( i!=0.0 ){
			this.scaleI = i;			
		}else{
			this.scaleI = r;			
		}
	}
	
	public MandelbrotSet(Point2D.Double leftTop,double scaleR,double scaleI){
		this.leftTop = new Point2D.Double(leftTop.x,leftTop.y);
		
		if( scaleR!=0.0 ){
			this.scaleR = scaleR;			
		}else{
			this.scaleR = scaleI;			
		}
		if( scaleI!=0.0 ){
			this.scaleI = scaleI;			
		}else{
			this.scaleI = scaleR;			
		}
	}
	
	public double getLeft(){
		return leftTop.getX();
	}

	public double getTop(){
		return leftTop.getY();
	}

	public double getScaleI() {
		return scaleI;
	}


	public double getScaleR() {
		return scaleR;
	}

	public int calcMandel(int r,int i,int max_count){
		return calcMandel(leftTop.getX()+r*scaleR , leftTop.getY()+i*scaleI ,max_count);
	}

	public int calcMandel(final double cr,final double ci,final int max_count){
		double r,i;
		double rr,ii;
		int n;

		r=0.0;
		i=0.0;
		rr = 0.0;
		ii = 0.0;
		for(n=0;n<=max_count;++n){
			i=(2.0*r*i)+ci;
			r=rr-ii+cr;
			rr=r*r;
			ii=i*i;
			if( (rr+ii)>4.0 ) return n;
		}
		return -1;
	}
	
	public String toString(){
		return String.format("(%e,%e):scale(%e,%e)", leftTop.x,leftTop.y ,scaleR, scaleI);
	}
	
	public boolean equals(Object o) {
		if( this==o) {
			return true;
		}
		if( o instanceof MandelbrotSet ) {
			MandelbrotSet m =(MandelbrotSet)o; 
			if( this.getLeft() != m.getLeft() ){ return false; }
			if( this.getTop() != m.getTop() ){ return false; }
			if( this.getScaleR() != m.getScaleR() ){ return false; }
			if( this.getScaleI() != m.getScaleI() ){ return false; }
			return true;
		}
		return false;
	}
	
	public int hashCode() {
		//  hashl̗LɂĂ͖؁BƂ肠B
		int hash = 1;
		hash = hash * 31 + (Double.valueOf(leftTop.x)).hashCode();
		hash = hash * 31 + (Double.valueOf(leftTop.y)).hashCode();
		hash = hash * 31 + (Double.valueOf(scaleR)).hashCode();
		hash = hash * 31 + (Double.valueOf(scaleI)).hashCode();
		return hash;
	}
}

==> MandelbrotExplorer_v1_24.jar: mandelbrotExplorer/MandelbrotSet.java <==
package mandelbrotExplorer;

import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.awt.image.BufferedImage;

public class MandelbrotSet {

	final private double scaleR,scaleI;
	final private Point2D.Double leftTop;
	private BufferedImage smallImage;

	public MandelbrotSet(int width,int height, Rectangle2D.Double rg){
		leftTop = new Point2D.Double(rg.x , rg.y);

		this.scaleR = rg.width/(double)width;
		this.scaleI = rg.height/(double)height;
		
	}
	
	public MandelbrotSet(Point2D.Double leftTop,double scaleR,double scaleI){
		this.leftTop = new Point2D.Double(leftTop.x,leftTop.y);
		
		this.scaleR = scaleR;			
		this.scaleI = scaleI;			
	}
	
	public MandelbrotSet(int width,int height, Rectangle2D.Double rg,double aspectRatio){
		leftTop = new Point2D.Double(rg.x , rg.y);

		if( aspectRatio!=0.0 ){
			//@scalȅcaspectRatioɍ킹B
			// iwidth,height)rg̑Ŝ[܂悤Ɂj
			if( width>=height ){
				scaleI = rg.height/(double)height;
				scaleR = scaleI * aspectRatio;
			}else{
				scaleR = rg.width/(double)width;
				scaleI = scaleR / aspectRatio;
			}
		}else{
			//@scalȅćAR|[lg̃TCYregionŌ߂
			this.scaleR = rg.width/(double)width;
			this.scaleI = rg.height/(double)height;
		}
	}
	
	public double getLeft(){
		return leftTop.getX();
	}

	public double getTop(){
		return leftTop.getY();
	}

	public double getScaleI() {
		return scaleI;
	}


	public double getScaleR() {
		return scaleR;
	}

	public int calcMandel(final int r,final int i,final int max_count){
		return calcMandel(leftTop.getX()+r*scaleR , leftTop.getY()+i*scaleI ,max_count);
	}

	public int calcMandel(final double cr,final double ci,final int max_count){
		double r,i;
		double rr,ii;
		int n;

		r=0.0;
		i=0.0;
		rr = 0.0;
		ii = 0.0;
		for(n=0;n<=max_count;++n){
			i=(2.0*r*i)+ci;
			r=rr-ii+cr;
			rr=r*r;
			ii=i*i;
			if( (rr+ii)>4.0 ) return n;
		}
		return -1;
	}
	
	public String toString(){
		return String.format("(%e,%e):scale(%e,%e)", leftTop.x,leftTop.y ,scaleR, scaleI);
	}
	
	public boolean equals(Object o) {
		if( this==o) {
			return true;
		}
		if( o instanceof MandelbrotSet ) {
			MandelbrotSet m =(MandelbrotSet)o; 
			if( this.getLeft() != m.getLeft() ){ return false; }
			if( this.getTop() != m.getTop() ){ return false; }
			if( this.getScaleR() != m.getScaleR() ){ return false; }
			if( this.getScaleI() != m.getScaleI() ){ return false; }
			return true;
		}
		return false;
	}
	
	public int hashCode() {
		//  hashl̗LɂĂ͖؁BƂ肠B
		int hash = 1;
		hash = hash * 31 + (Double.valueOf(leftTop.x)).hashCode();
		hash = hash * 31 + (Double.valueOf(leftTop.y)).hashCode();
		hash = hash * 31 + (Double.valueOf(scaleR)).hashCode();
		hash = hash * 31 + (Double.valueOf(scaleI)).hashCode();
		return hash;
	}

	public final BufferedImage getSmallImage() {
		return smallImage;
	}

	public final void setSmallImage(BufferedImage smallImage) {
		this.smallImage = new BufferedImage(smallImage.getWidth(),smallImage.getHeight(), BufferedImage.TYPE_INT_BGR);
		this.smallImage.createGraphics().drawImage(smallImage, null, 0, 0);
	}
}
